# -*- coding: utf-8 -*-

"""
Top-level module for Countdoom.

SPDX-License-Identifier: MIT
"""

from countdoom import cli  # pylint: disable=C0415

if __name__ == "__main__":
    cli.cli()
